\docType{package}
\encoding{UTF-8}
\name{GMCPIC-package}
\alias{GMCPIC}
\alias{GMCPIC-package}
\title{Package implementing the Generalized Monte Carlo plug-in test with calibration (GMCPIC test)}
\description{
Computer intensive procedure to test equality of the probability vectors
of two multinomial draws. This procedure was specifically designed to handle small samples and sparse data.
}
\details{
\tabular{ll}{ Package: \tab GMCPIC\cr Type: \tab Package\cr
Version: \tab 1.2\cr Date: \tab 2017-07-07\cr License: \tab
GPL (>=2)\cr } The GMCPIC package implements the
Generalized Monte Carlo plug-in test with calibration
proposed in Soubeyrand et al. (2017). This procedure can be
used to test the equality of the vectors of probabilities
of two multinomial draws. This test was developed to test
the similarity of two pathogen compositions based on small
samples and sparse data. Data sets analyzed in Soubeyrand
et al. (2015) are provided in this package.
}
\examples{
## Load Pathogen Compositions of M. oryzae collected in Madagascar
data(PathogenCompositionMoryzaeMadagascar)
x=t(PathogenCompositionMoryzaeMadagascar)

## Apply the GMCPIC test (use B=10^3, M=10^4 to get a robust result)
testMada=gmcpic.test(x, B=10^1, M=10^1, weights=seq(0.5,0.99,by=0.01),threshold=0.05)
testMada

## Apply the Chi-squared test
chisq.test(x, simulate.p.value = TRUE, B = 10000)
}
\author{
Samuel Soubeyrand \email{samuel.soubeyrand@inra.fr}

Vincent Garreta

Jean-Francois Rey \email{jean-francois.rey@inra.fr}
}
\references{
Soubeyrand S, Garreta V, Monteil C, Suffert F, Goyeau H,
Berder J, Moinard J, Fournier E, Tharreau D,
Morris C, Sache I (2017). Testing differences between
pathogen compositions with small samples and sparse data.
Phytopathology. http://doi.org/10.1094/PHYTO-02-17-0070-FI
}
\seealso{
\code{\link{gmcpic.test}},
\code{\link[stats:chisq.test]{stats:chisq.test}}
}
\keyword{package}

